@@ -50,6 +50,7 @@ def save_benchmark(
         columns: list,
         model_type: str,
         gdrive_path=GDRIVE_PATH,
+        replace=False
 ):
     """
     save benchmarks into json structure:
@@ -69,7 +70,7 @@ def save_benchmark(
     actual_tt_json_path = os.path.join(env_path, model_type, "trained_tt.json")
     _ensure_dir(actual_tt_json_path)
     model_index = None
-    if not os.path.exists(actual_tt_json_path):
+    if not os.path.exists(actual_tt_json_path) or replace == True:
         actual_tt_json = collections.defaultdict(dict)
         _write_json(actual_tt_json, actual_tt_json_path)
         model_index = 0
